# Partitioneer
Utilities for managing data files in a date partitioned format

**Build the package:**
```sh
python setup.py sdist bdist_wheel
```

**Upload to PyPI:**
```sh
pip install twine
twine upload dist/*
```